ArbosState

Struct ArbosState 

pub struct ArbosState<D, B: Burner> {
Show 27 fields pub arbos_version: u64, pub max_arbos_version_supported: u64, pub upgrade_version: StorageBackedUint64<D>, pub upgrade_timestamp: StorageBackedUint64<D>, pub network_fee_account: StorageBackedAddress<D>, pub l1_pricing_state: L1PricingState<D>, pub l2_pricing_state: L2PricingState<D>, pub retryable_state: RetryableState<D>, pub address_table: AddressTable<D>, pub chain_owners: AddressSet<D>, pub send_merkle_accumulator: MerkleAccumulator<D>, pub programs: Programs<D>, pub blockhashes: Blockhashes<D>, pub chain_id: StorageBackedBigUint<D>, pub chain_config: StorageBackedBytes<D>, pub genesis_block_num: StorageBackedUint64<D>, pub infra_fee_account: StorageBackedAddress<D>, pub brotli_compression_level: StorageBackedUint64<D>, pub backing_storage: Storage<D>, pub burner: B, pub native_token_enabled_from_time: StorageBackedUint64<D>, pub native_token_owners: AddressSet<D>, pub transaction_filtering_enabled_from_time: StorageBackedUint64<D>, pub transaction_filterers: AddressSet<D>, pub features: Features<D>, pub filtered_funds_recipient: StorageBackedAddress<D>, pub filtered_transactions: FilteredTransactionsState<D>,
}
Central ArbOS state aggregating all subsystem states.

Fields

arbos_version: u64max_arbos_version_supported: u64upgrade_version: StorageBackedUint64<D>upgrade_timestamp: StorageBackedUint64<D>network_fee_account: StorageBackedAddress<D>l1_pricing_state: L1PricingState<D>l2_pricing_state: L2PricingState<D>retryable_state: RetryableState<D>address_table: AddressTable<D>chain_owners: AddressSet<D>send_merkle_accumulator: MerkleAccumulator<D>programs: Programs<D>blockhashes: Blockhashes<D>chain_id: StorageBackedBigUint<D>chain_config: StorageBackedBytes<D>genesis_block_num: StorageBackedUint64<D>infra_fee_account: StorageBackedAddress<D>brotli_compression_level: StorageBackedUint64<D>backing_storage: Storage<D>burner: Bnative_token_enabled_from_time: StorageBackedUint64<D>native_token_owners: AddressSet<D>transaction_filtering_enabled_from_time: StorageBackedUint64<D>transaction_filterers: AddressSet<D>features: Features<D>filtered_funds_recipient: StorageBackedAddress<D>filtered_transactions: FilteredTransactionsState<D>

Implementations

Source

impl<D: Database, B: Burner> ArbosState<D, B>

pub fn open(state: *mut State<D>, burner: B) -> Result<Self, ()>

Open existing ArbOS state from storage.

pub fn arbos_version(&self) -> u64

pub fn backing_storage(&self) -> &Storage<D>

pub fn set_format_version(&mut self, version: u64) -> Result<(), ()>

pub fn brotli_compression_level(&self) -> Result<u64, ()>

pub fn set_brotli_compression_level(&self, level: u64) -> Result<(), ()>

pub fn chain_id(&self) -> Result<U256, ()>

pub fn chain_config(&self) -> Result<Vec<u8>, ()>

pub fn set_chain_config(&self, config: &[u8]) -> Result<(), ()>

pub fn genesis_block_num(&self) -> Result<u64, ()>

pub fn network_fee_account(&self) -> Result<Address, ()>

pub fn set_network_fee_account(&self, account: Address) -> Result<(), ()>

pub fn infra_fee_account(&self) -> Result<Address, ()>

pub fn set_infra_fee_account(&self, account: Address) -> Result<(), ()>

pub fn filtered_funds_recipient(&self) -> Result<Address, ()>

pub fn filtered_funds_recipient_or_default(&self) -> Result<Address, ()>

pub fn set_filtered_funds_recipient(&self, addr: Address) -> Result<(), ()>

pub fn native_token_management_from_time(&self) -> Result<u64, ()>

pub fn set_native_token_management_from_time(&self, time: u64) -> Result<(), ()>

pub fn transaction_filtering_from_time(&self) -> Result<u64, ()>

pub fn set_transaction_filtering_from_time(&self, time: u64) -> Result<(), ()>

pub fn get_scheduled_upgrade(&self) -> Result<(u64, u64), ()>

pub fn schedule_arbos_upgrade( &self, version: u64, timestamp: u64, ) -> Result<(), ()>

pub fn upgrade_arbos_version_if_necessary( &mut self, current_timestamp: u64, ) -> Result<(), ()>

Checks and performs a scheduled ArbOS version upgrade if due.

pub fn upgrade_arbos_version( &mut self, upgrade_to: u64, first_time: bool, ) -> Result<(), ()>

Performs version upgrade steps from current version up to upgrade_to.

first_time is true during genesis initialization, which affects some initial parameter values.