pub fn finalize_block_header_info(
send_root: B256,
send_count: u64,
l1_block_number: u64,
arbos_version: u64,
) -> ArbHeaderInfoExpand description
Compute the Arbitrum header info to finalize a block.
This corresponds to FinalizeBlock which sets header fields from ArbOS state.
We derive the info and let the block assembler apply it.