pub fn arbos_l1_block_number_slot() -> (Address, B256)Expand description
Get the storage address and slot for the ArbOS L1 block number.
pub fn arbos_l1_block_number_slot() -> (Address, B256)Get the storage address and slot for the ArbOS L1 block number.