byte_count_after_brotli_level

Function byte_count_after_brotli_level 

pub fn byte_count_after_brotli_level(data: &[u8], level: u64) -> u64
Computes the brotli-compressed size at a given compression level.

Uses BrotliCompressCustomAlloc with a full-size input buffer to process the entire input in a single shot. The standard BrotliCompress uses a 4096-byte chunked input buffer which produces different output for inputs exceeding that size.