parsed_tx_to_signed

Function parsed_tx_to_signed 

pub fn parsed_tx_to_signed(
    parsed: &ParsedTransaction,
    chain_id: u64,
) -> Option<ArbTransactionSigned>
Convert a ParsedTransaction into an ArbTransactionSigned.

The chain_id is needed for constructing Arbitrum-specific tx envelopes. Returns None for batch posting reports and internal start-block txs that are constructed separately by the internal tx module.