pub struct SubmitRetryableFees {Show 13 fields
pub submission_fee: U256,
pub submission_fee_refund: U256,
pub escrow: Address,
pub timeout: u64,
pub can_pay_for_gas: bool,
pub gas_cost: U256,
pub infra_cost: U256,
pub network_cost: U256,
pub gas_price_refund: U256,
pub gas_cost_refund: U256,
pub available_refund: U256,
pub withheld_submission_fee: U256,
pub error: Option<String>,
}Expand description
Computed fee distribution for a submit retryable transaction.
The caller should execute the following operations in order:
- Mint
deposit_valuetofrom - Transfer
submission_feefromfromto network fee account - Transfer
submission_fee_refundfromfromto fee refund address - Transfer
retry_valuefromfromtoescrow - Create retryable ticket with
timeout - If
can_pay_for_gas:- Transfer
infra_costfromfromto infra fee account - Transfer
network_costfromfromto network fee account - Transfer
gas_price_refundfromfromto fee refund address - Schedule auto-redeem with
available_refundas max refund
- Transfer
- If not
can_pay_for_gas: refundgas_cost_refundto fee refund address
Fields
submission_fee: U256The actual submission fee.
submission_fee_refund: U256Excess submission fee to refund.
escrow: AddressEscrow address for the retryable’s call value.
timeout: u64Retryable ticket timeout.
can_pay_for_gas: boolWhether the user can pay for gas.
gas_cost: U256Total gas cost (effective_base_fee * gas).
infra_cost: U256Infra fee portion of gas cost (ArbOS v11+).
network_cost: U256Network fee portion (gas_cost - infra_cost).
gas_price_refund: U256Gas price refund ((gas_fee_cap - effective_base_fee) * gas).
gas_cost_refund: U256If user can’t pay for gas, this amount should be refunded.
available_refund: U256Remaining L1 deposit available for auto-redeem max refund.
withheld_submission_fee: U256Withheld submission fee (for error path refunds).
error: Option<String>Error if validation fails.