transfer_balance

Function transfer_balance 

pub fn transfer_balance<F>(
    from: Option<&Address>,
    to: Option<&Address>,
    amount: U256,
    state_fn: F,
) -> Result<(), ()>
where F: FnMut(Option<&Address>, Option<&Address>, U256) -> Result<(), ()>,
Transfers balance between two addresses.

If from is None, this is a mint operation. If to is None, this is a burn operation.