L1PricingState

Struct L1PricingState 

pub struct L1PricingState<D> {
    pub backing_storage: Storage<D>,
    pub arbos_version: u64,
    /* private fields */
}
L1 pricing state manages the cost model for L1 data posting.

Fields

backing_storage: Storage<D>arbos_version: u64

Implementations

Source

impl<D: Database> L1PricingState<D>

pub fn open(sto: Storage<D>, arbos_version: u64) -> Self

pub fn initialize( sto: &Storage<D>, rewards_recipient: Address, initial_l1_base_fee: U256, )

pub fn batch_poster_table(&self) -> BatchPostersTable<D>

pub fn pay_rewards_to(&self) -> Result<Address, ()>

pub fn set_pay_rewards_to(&self, addr: Address) -> Result<(), ()>

pub fn equilibration_units(&self) -> Result<U256, ()>

pub fn set_equilibration_units(&self, units: U256) -> Result<(), ()>

pub fn inertia(&self) -> Result<u64, ()>

pub fn set_inertia(&self, val: u64) -> Result<(), ()>

pub fn per_unit_reward(&self) -> Result<u64, ()>

pub fn set_per_unit_reward(&self, val: u64) -> Result<(), ()>

pub fn last_update_time(&self) -> Result<u64, ()>

pub fn set_last_update_time(&self, time: u64) -> Result<(), ()>

pub fn funds_due_for_rewards(&self) -> Result<U256, ()>

pub fn set_funds_due_for_rewards(&self, val: U256) -> Result<(), ()>

pub fn units_since_update(&self) -> Result<u64, ()>

pub fn set_units_since_update(&self, val: u64) -> Result<(), ()>

pub fn add_to_units_since_update(&self, units: u64) -> Result<(), ()>

pub fn subtract_from_units_since_update(&self, units: u64) -> Result<(), ()>

pub fn price_per_unit(&self) -> Result<U256, ()>

pub fn set_price_per_unit(&self, val: U256) -> Result<(), ()>

pub fn last_surplus(&self) -> Result<(U256, bool), ()>

pub fn set_last_surplus( &self, magnitude: U256, negative: bool, ) -> Result<(), ()>

pub fn per_batch_gas_cost(&self) -> Result<i64, ()>

pub fn set_per_batch_gas_cost(&self, val: i64) -> Result<(), ()>

pub fn amortized_cost_cap_bips(&self) -> Result<u64, ()>

pub fn set_amortized_cost_cap_bips(&self, val: u64) -> Result<(), ()>

pub fn l1_fees_available(&self) -> Result<U256, ()>

pub fn set_l1_fees_available(&self, val: U256) -> Result<(), ()>

pub fn add_to_l1_fees_available(&self, amount: U256) -> Result<(), ()>

pub fn transfer_from_l1_fees_available(&self, amount: U256) -> Result<U256, ()>

pub fn parent_gas_floor_per_token(&self) -> Result<u64, ()>

pub fn set_parent_gas_floor_per_token(&self, val: u64) -> Result<(), ()>

pub fn get_l1_pricing_surplus(&self) -> Result<(U256, bool), ()>

pub fn get_poster_info(&self, poster: Address) -> Result<(U256, Address), ()>

pub fn poster_data_cost(&self, calldata_units: u64) -> Result<U256, ()>

pub fn compute_poster_cost( &self, poster: Address, tx_bytes: &[u8], brotli_compression_level: u64, ) -> Result<(U256, u64), ()>

Compute poster cost and units for a transaction on-chain.

Returns (l1_fee, units) where l1_fee = price_per_unit * units.

pub fn poster_data_cost_for_estimation( &self, tx_bytes: &[u8], brotli_compression_level: u64, ) -> Result<(U256, u64), ()>

Compute poster data cost for gas estimation (with padding).

Used when we don’t have an actual signed transaction, e.g. during eth_estimateGas. Applies padding to account for tx encoding overhead.

pub fn get_poster_units_without_cache( &self, tx_bytes: &[u8], brotli_compression_level: u64, ) -> u64

Compute the L1 calldata units for a transaction.

Compresses the tx bytes with brotli and multiplies by the EIP-2028 non-zero gas cost (16) to get the unit count.

pub fn update_for_batch_poster_spending<F>( &self, update_time: u64, current_time: u64, batch_poster: Address, wei_spent: U256, l1_basefee: U256, transfer_fn: F, ) -> Result<(), ()>
where F: FnMut(Address, Address, U256) -> Result<(), ()>,

Update pricing based on a batch poster spending report.