pub fn transfer_balance<F>(
from: Option<&Address>,
to: Option<&Address>,
amount: U256,
state_fn: F,
) -> Result<(), ()>Expand description
Transfers balance between two addresses.
If from is None, this is a mint operation.
If to is None, this is a burn operation.